# Generated by Django 6.0.2 on 2026-02-05 06:50

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0018_remove_order_recipe_alter_order_total_price_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="order",
            name="tracking_token",
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
    ]
