# Generated by Django 6.0.1 on 2026-01-28 12:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0016_user_theme"),
    ]

    operations = [
        migrations.AddField(
            model_name="setting",
            name="gotify_token",
            field=models.CharField(
                blank=True,
                help_text="The application token for Gotify",
                max_length=255,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="setting",
            name="gotify_url",
            field=models.URLField(
                blank=True,
                help_text="The URL of your Gotify server (e.g., https://gotify.example.com)",
                null=True,
            ),
        ),
    ]
